proc ss { file } {
		
       	set coord [ open $file r+ ]
       	set filecontents [read $coord]
       	set lines [ split [string trim $filecontents] \n]
		
		set out [ open SS-chis-summary_$file.dat w ]
		set out2 [ open SS-measures_$file.dat w ]
		
		puts $out2 "#frame\t#chi1\t#chi2\t#chi3\t#chi2_prime\t#chi1_prime\t#strain_energy\t#S-S_dist\t#Class"
	
			foreach line $lines {

               	if { [string match *SSBOND* $line] } {

						set cys1 [ lindex $line 4 ]
                       	set cys2 [ lindex $line 7 ]
                       	set index_C1 [[ atomselect top "resid $cys1 and noh" ] get index]
                       	set index_C2 [[ atomselect top "resid $cys2 and noh" ] get index]
                       	set names_C1 [[ atomselect top "resid $cys1 and noh" ] get name]
                       	set names_C2 [[ atomselect top "resid $cys2 and noh" ] get name]
						
						# Print atom numbers for user reference:
						puts $out "The atom numbers of disulphide bond between C$cys1 and C$cys2 are:"
                       	puts $out $index_C1
                       	puts $out $index_C2
						# Print atom names for user reference:
						puts $out "The above atom numbers refer to the following atom names:"
                       	puts $out $names_C1
                       	puts $out $names_C2
                       	#puts $out2 "S-S bond between C$cys1-C$cys2\n"
						
						# Now work on the lists to calculate the chi angles
						# Iterate over n frames if any
						
						set numframes [molinfo top get numframes]	
						set all [atomselect top "all"]
						
						for { set i 0 } { $i < $numframes } { incr i } {
							
							animate goto $i
							
							$all frame $i 
							$all update
							
							set chi1 [ format {%0.2f} [ measure dihed [list [lindex $index_C1 0] [lindex $index_C1 1] [lindex $index_C1 4] [lindex $index_C1 5] ]]]
							set chi2 [ format {%0.2f} [ measure dihed [list [lindex $index_C1 1] [lindex $index_C1 4] [lindex $index_C1 5] [lindex $index_C2 5] ]]]
							set chi3 [ format {%0.2f} [ measure dihed [list [lindex $index_C1 4] [lindex $index_C1 5] [lindex $index_C2 5] [lindex $index_C2 4] ]]]
							set chi2_prime [ format {%0.2f} [ measure dihed [list [lindex $index_C1 5] [lindex $index_C2 5] [lindex $index_C2 4] [lindex $index_C2 1] ]]]
							set chi1_prime [ format {%0.2f} [ measure dihed [list [lindex $index_C2 5] [lindex $index_C2 4] [lindex $index_C2 1] [lindex $index_C2 0] ]]]
							
							set chi1_rad [ format {%0.2f} [ expr $chi1 / 57.2958 ]]
							set chi2_rad [ format {%0.2f} [ expr $chi2 / 57.2958 ]]
							set chi3_rad [ format {%0.2f} [ expr $chi3 / 57.2958 ]]
							set chi2_prime_rad [ format {%0.2f} [ expr $chi2_prime / 57.2958 ]]
							set chi1_prime_rad [ format {%0.2f} [ expr $chi1_prime / 57.2958 ]]
							
						# Now calculate the energy for the disulfide bonds
						
						# Energy of a bond in Kj/mol is give by the following formula: 
						
						# 			E = 8.37*(1 + cos(3*chi1)) + 8.37*(1 + cos(3*chi1_prime)) + 4.18*(1 + cos(3*chi2)) + 4.18*(1 + cos(3*chi2_prime)) + \
						#				14.64*(1 + cos(2*chi3)) + 2.51*(1 + cos(3*chi3))
						
							set energy [ format {%0.2f} [ expr (8.37*(1 + cos(3*$chi1_rad))) + (8.37*(1 + cos(3*$chi1_prime_rad))) + (4.18*(1 + cos(3*$chi2_rad))) + \
							(4.18*(1 + cos(3*$chi2_prime_rad))) + (14.64*(1 + cos(2*$chi3_rad))) + (2.51*(1 + cos(3*$chi3_rad))) ]]
						
						# Now calculate the distance between the two C-alpha
						
							set SS_dist [ format {%0.2f} [ measure bond [list [lindex $index_C1 5] [lindex $index_C2 5]]]]
						
							puts  $out "The following angles will be calculated:\n"
							puts  $out "Angle chi1 - dihedral angle composed by bonded atoms: [list [lindex $names_C1 0] [lindex $names_C1 1] [lindex $names_C1 4] [lindex $names_C1 5]]"
                       		puts  $out "The value of the chi1 angle is: $chi1 degrees\n"
							puts  $out "Angle chi2 - dihedral angle composed by bonded atoms: [list [lindex $names_C1 1] [lindex $names_C1 4] [lindex $names_C1 5] [lindex $names_C2 5]]"
							puts  $out "The value of the chi2 angle is: $chi2 degrees\n"
							puts  $out "Angle chi3 - dihedral angle composed by bonded atoms: [list [lindex $names_C1 4] [lindex $names_C1 5] [lindex $names_C2 5] [lindex $names_C2 4]]"
							puts  $out "The value of the chi3 angle is: $chi3 degrees\n"
							puts  $out "Angle chi2_prime - dihedral angle composed by bonded atoms: [list [lindex $names_C1 5] [lindex $names_C2 5] [lindex $names_C2 4] [lindex $names_C2 1]]"
							puts  $out "The value of the chi2-prime angle is: $chi2_prime degrees\n"
							puts  $out "Angle chi1_prime - dihedral angle composed by bonded atoms: [list [lindex $names_C2 5] [lindex $names_C2 4] [lindex $names_C2 1] [lindex $names_C2 0]]"
							puts  $out "The value of the chi1-prime angle is: $chi1_prime degrees\n"
						
							puts  $out "The following is the energy: $energy kJ/mol\n"

							puts  $out "The Calpha - Calpha distance is: $SS_dist Angstroms\n"
						
						# Now set the class
						
						if {( $chi1 < 0  && $chi2 < 0 && $chi3 < 0 && $chi2_prime < 0 && $chi1_prime < 0 )} {
							puts  $out "The angle belongs to the -LHSpiral"
							set class -LHSpiral
							} elseif {( $chi1 < 0  && $chi2 > 0 && $chi3 > 0 && $chi2_prime < 0 && $chi1_prime < 0  )} {
							puts  $out "The angle belongs to the -RHHook"
							set class -RHHook
							} elseif {( $chi1 > 0  && $chi2 < 0 && $chi3 < 0 && $chi2_prime < 0 && $chi1_prime < 0  )} {
							puts  $out "The angle belongs to the +/-LHSpiral"
							set class +/-LHSpiral
							} elseif {( $chi1 < 0  && $chi2 < 0 && $chi3 < 0 && $chi2_prime > 0 && $chi1_prime < 0  )} {
							puts  $out "The angle belongs to the -LHHook"
							set class -LHHook
							} elseif {( $chi1 > 0  && $chi2 > 0 && $chi3 > 0 && $chi2_prime < 0 && $chi1_prime < 0  )} {
							puts  $out "The angle belongs to the -/+RHHook"
							set class -/+RHHook
							} elseif {( $chi1 < 0  && $chi2 < 0 && $chi3 > 0 && $chi2_prime < 0 && $chi1_prime < 0  )} {
							puts  $out "The angle belongs to the -RHStaple"
							set class -RHStaple
							} elseif {( $chi1 > 0  && $chi2 > 0 && $chi3 > 0 && $chi2_prime > 0 && $chi1_prime < 0  )} {
							puts  $out "The angle belongs to the +/-RHSpiral"
							set class +/-RHSpiral
							} elseif {( $chi1 < 0  && $chi2 > 0 && $chi3 > 0 && $chi2_prime > 0 && $chi1_prime < 0  )} {
							puts  $out "The angle belongs to the -RHSpiral"
							set class -RHSpiral
							} elseif {( $chi1 > 0  && $chi2 > 0 && $chi3 < 0 && $chi2_prime < 0 && $chi1_prime < 0  )} {
							puts  $out "The angle belongs to the -/+LHHook"
							set class -/+LHHook
							} elseif {( $chi1 > 0  && $chi2 < 0 && $chi3 < 0 && $chi2_prime > 0 && $chi1_prime < 0  )} {
							puts  $out "The angle belongs to the +/-LHHook"
							set class +/-LHHook
							} elseif {( $chi1 > 0  && $chi2 > 0 && $chi3 < 0 && $chi2_prime > 0 && $chi1_prime < 0  )} {
							puts  $out "The angle belongs to the +/-LHStaple"
							set class +/-LHStaple
							} elseif {( $chi1 < 0  && $chi2 > 0 && $chi3 < 0 && $chi2_prime > 0 && $chi1_prime < 0  )} {
							puts  $out "The angle belongs to the -LHStaple"
							set class -LHStaple
							} elseif {( $chi1 > 0  && $chi2 < 0 && $chi3 < 0 && $chi2_prime > 0 && $chi1_prime > 0  )} {
							puts  $out "The angle belongs to the -LHHook"
							set class -LHHook
							} elseif {( $chi1 > 0  && $chi2 < 0 && $chi3 < 0 && $chi2_prime < 0 && $chi1_prime > 0  )} {
							puts  $out "The angle belongs to the +LHSpiral"
							set class +LHSpiral
							} elseif {( $chi1 > 0  && $chi2 < 0 && $chi3 > 0 && $chi2_prime < 0 && $chi1_prime < 0  )} {
							puts  $out "The angle belongs to the +/-RHStaple"
							set class +/-RHStaple
							} elseif {( $chi1 > 0  && $chi2 > 0 && $chi3 > 0 && $chi2_prime < 0 && $chi1_prime > 0  )} {
							puts  $out "The angle belongs to the +RHHook"
							set class +RHHook
							} elseif {( $chi1 > 0  && $chi2 < 0 && $chi3 > 0 && $chi2_prime < 0 && $chi1_prime > 0  )} {
							puts  $out "The angle belongs to the +RHStaple"
							set class +RHStaple
							} elseif {( $chi1 > 0  && $chi2 > 0 && $chi3 < 0 && $chi2_prime > 0 && $chi1_prime > 0  )} {
							puts  $out "The angle belongs to the +LHStaple"
							set class +LHStaple
							} else { puts $out "I couldn't Identify the class to which the bond belongs?"
							set class None } 
							puts ""
							puts "Angles calculated for $cys1-$cys2 bonds. Check the S-S_chis_resume.dat output file"
							puts $out2 "$i\t$chi1\t$chi2\t$chi3\t$chi2_prime\t$chi1_prime\t$energy\t$SS_dist\t$class"
              			}
						
					}
       	}
close $coord
close $out
close $out2
}